
.. image:: https://readthedocs.org/projects/panopticon-single-cell/badge/?version=latest
    :target: https://panopticon-single-cell.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status
    
.. image:: https://github.com/scyrusm/panopticon/workflows/build/badge.svg 
    :target: https://github.com/scyrusm/panopticon 
    :alt: Build Status
    
.. image:: https://zenodo.org/badge/215686178.svg
   :target: https://zenodo.org/badge/latestdoi/215686178
   :alt: DOI

Panopticon
==========

.. figure:: https://upload.wikimedia.org/wikipedia/en/e/e1/Panopticon_Willey_Reveley_1791.png
   :alt: Utopian data structure



Additional Documentation
========================

For more in-depth documentation, see panopticon's `Read the
Docs <https://panopticon-single-cell.readthedocs.io>`__ page.

